==> PerlPowerTools-1.028.tar.gz: PerlPowerTools-1.028/CONTRIBUTING.md <==
# Contributing to this project

PerlPowerTools is a collection of scripts that reproduce the behavior
of standard unix tools so you can use the same commands on non-Unix
systems.

This is designed as a drop-in installation, so comes with some unusual
requirements.

* Works on Perl v5.8
* Uses only core modules (with very few exceptions)
* Uses the Artistic License 2
* Works on Windows

Many of these scripts were written around the time of Perl v5.6, so the
style and idioms you may encounter can be quite archaic. Feel free to
update those, but only up to v5.8.

Before you go crazy with huge changes, make some small pull requests to
check that we want to change the tools in that way. Pull requests that
have one logical change are better.

There's a Perl::Critic test is *xt/perlcritic.t*. Your new code or fixes
should at least pass all those checks. Many are disabled because they are
a problem across the code base (and there aren't tests).

For new programs, include tests with as high a coverage as you can
stand.

<a name="pull-requests"></a>
## Pull requests

Good pull requests - patches, improvements, new features - are a fantastic
help. They should remain focused in scope and avoid containing unrelated
commits.

**Please ask first** before embarking on any significant pull request (e.g.
implementing features, refactoring code, porting to a different language),
otherwise you risk spending a lot of time working on something that the
project's developers might not want to merge into the project.

Please adhere to the coding conventions used throughout a project (indentation,
accurate comments, etc.) and any other requirements (such as test coverage).

Follow this process if you'd like your work considered for inclusion in the
project:

1. [Fork](http://help.github.com/fork-a-repo/) the project, clone your fork,
   and configure the remotes:

   ```bash
   # Clone your fork of the repo into the current directory
   git clone https://github.com/<your-username>/<repo-name>
   # Navigate to the newly cloned directory
   cd <repo-name>
   # Assign the original repo to a remote called "upstream"
   git remote add upstream https://github.com/<upstream-owner>/<repo-name>
   ```

2. If you cloned a while ago, get the latest changes from upstream:

   ```bash
   git checkout <dev-branch>
   git pull upstream <dev-branch>
   ```

3. Create a new topic branch (off the main project development branch) to
   contain your feature, change, or fix:

   ```bash
   git checkout -b <topic-branch-name>
   ```

4. Commit your changes in logical chunks. Please make your git commit message detailed and specific
   or your code is unlikely be merged into the main project. Use Git's
   [interactive rebase](https://help.github.com/articles/interactive-rebase)
   feature to tidy up your commits before making them public.

5. Locally merge (or rebase) the upstream development branch into your topic branch:

   ```bash
   git pull [--rebase] upstream <dev-branch>
   ```

6. Push your topic branch up to your fork:

   ```bash
   git push origin <topic-branch-name>
   ```

7. [Open a Pull Request](https://help.github.com/articles/using-pull-requests/)
    with a clear title and description.

**IMPORTANT**: By submitting a patch, you agree to allow the project owner to
license your work under the same license as that used by the project.

==> PerlPowerTools-1.033_03.tar.gz: PerlPowerTools-1.033_03/CONTRIBUTING.md <==
# Contributing to this project

PerlPowerTools is a collection of scripts that reproduce the behavior
of standard unix tools so you can use the same commands on non-Unix
systems.

This is designed as a drop-in installation, so comes with some unusual
requirements.

* Works on Perl v5.8
* Uses only core modules (with very few exceptions)
* Uses the Artistic License 2
* Works on Windows

Many of these scripts were written around the time of Perl v5.6, so the
style and idioms you may encounter can be quite archaic. Feel free to
update those, but only up to v5.8.

Before you go crazy with huge changes, make some small pull requests to
check that we want to change the tools in that way. Pull requests that
have one logical change are better.

There's a Perl::Critic test is *xt/perlcritic.t*. Your new code or fixes
should at least pass all those checks. Many are disabled because they are
a problem across the code base (and there aren't tests).

## Adding a new program

New programs follow the same general rules, but there are some extra
things you need to do:

* Add the program name to *lib/PerlPowerTools.pm*
* Add the program to the lists in *index.html*, *ru/index.html*, and *uk/index.html* in the gh-pages branch
* Run `make manifest` and check that it adds your new command and tests

For new programs, include tests with as high a coverage as you can
stand.

<a name="pull-requests"></a>
## Pull requests

Good pull requests - patches, improvements, new features - are a fantastic
help. They should remain focused in scope and avoid containing unrelated
commits.

**Please ask first** before embarking on any significant pull request (e.g.
implementing features, refactoring code, porting to a different language),
otherwise you risk spending a lot of time working on something that the
project's developers might not want to merge into the project.

Please adhere to the coding conventions used throughout a project (indentation,
accurate comments, etc.) and any other requirements (such as test coverage).

Follow this process if you'd like your work considered for inclusion in the
project:

1. [Fork](http://help.github.com/fork-a-repo/) the project, clone your fork,
   and configure the remotes:

   ```bash
   # Clone your fork of the repo into the current directory
   git clone https://github.com/<your-username>/<repo-name>
   # Navigate to the newly cloned directory
   cd <repo-name>
   # Assign the original repo to a remote called "upstream"
   git remote add upstream https://github.com/<upstream-owner>/<repo-name>
   ```

2. If you cloned a while ago, get the latest changes from upstream:

   ```bash
   git checkout <dev-branch>
   git pull upstream <dev-branch>
   ```

3. Create a new topic branch (off the main project development branch) to
   contain your feature, change, or fix:

   ```bash
   git checkout -b <topic-branch-name>
   ```

4. Commit your changes in logical chunks. Please make your git commit message detailed and specific
   or your code is unlikely be merged into the main project. Use Git's
   [interactive rebase](https://help.github.com/articles/interactive-rebase)
   feature to tidy up your commits before making them public.

5. Locally merge (or rebase) the upstream development branch into your topic branch:

   ```bash
   git pull [--rebase] upstream <dev-branch>
   ```

6. Push your topic branch up to your fork:

   ```bash
   git push origin <topic-branch-name>
   ```

7. [Open a Pull Request](https://help.github.com/articles/using-pull-requests/)
    with a clear title and description.

**IMPORTANT**: By submitting a patch, you agree to allow the project owner to
license your work under the same license as that used by the project.
